package xyz.leomurca.csgomatches.ui.screens.matches

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import xyz.leomurca.csgomatches.domain.model.Match
import xyz.leomurca.csgomatches.domain.model.Resource
import xyz.leomurca.csgomatches.domain.repository.MatchRepository
import javax.inject.Inject

@HiltViewModel
class MatchesViewModel @Inject constructor(
    private val matchRepository: MatchRepository
) : ViewModel() {

    private val _uiState = MutableStateFlow<MatchesUiState>(MatchesUiState.Loading)
    val uiState: StateFlow<MatchesUiState> = _uiState.asStateFlow()

    init {
        loadUpcomingMatches()
    }

    fun loadUpcomingMatches() {
        viewModelScope.launch {
            _uiState.value = MatchesUiState.Loading
            _uiState.value = when (val result = matchRepository.upcomingMatches()) {
                is Resource.Success -> MatchesUiState.Success(result.data)
                is Resource.Error -> MatchesUiState.Error(result.message)
            }
        }
    }

    sealed class MatchesUiState {
        object Loading : MatchesUiState()
        data class Success(val matches: List<Match>) : MatchesUiState()
        data class Error(val message: String) : MatchesUiState()
    }
}